==> pbbam_1.0.6+dfsg.orig.tar.xz: pbbam-1.0.6/include/pbbam/ZmwChunkedFastaReader.h <==
// File Description
/// \file ZmwChunkedFastaReader.h
/// \brief Defines the ZmwChunkedFastaReader class.
//
// Author: Derek Barnett

#ifndef ZMWCHUNKEDFASTAREADER_H
#define ZMWCHUNKEDFASTAREADER_H

#include "pbbam/Config.h"

#include <memory>
#include <string>
#include <vector>

#include "pbbam/FastaSequence.h"
#include "pbbam/internal/QueryBase.h"

namespace PacBio {
namespace BAM {

///
/// \brief The ZmwChunkedFastaReader provides sequential access to FASTA records,
///         where iteration is bounded by chunks of (unique) ZMWs.
///
class ZmwChunkedFastaReader : public internal::QueryBase<FastaSequence>
{
public:
    ///
    /// Construct a new ZMW-chunked FASTA reader.
    ///
    /// \param fn           FASTA file, must have a *.fai index
    /// \param numChunks    desired number of chunks
    ///
    /// Actual chunk count may be smaller than the requested number, if the input
    /// size is smaller.
    ///
    ZmwChunkedFastaReader(const std::string& fn, const size_t numChunks);

    ZmwChunkedFastaReader(ZmwChunkedFastaReader&&) noexcept;
    ZmwChunkedFastaReader& operator=(ZmwChunkedFastaReader&&) noexcept;
    ~ZmwChunkedFastaReader();

    ///
    /// \returns the number of chunks available.
    ///
    /// Actual chunk count may be smaller than the requested number, if the input
    /// size is smaller.
    ///
    size_t NumChunks() const;

    ///
    /// Sets current chunk to start iterating over.
    ///
    ZmwChunkedFastaReader& Chunk(size_t chunkId);

    ///
    /// \returns the current chunk in use
    ///
    size_t Chunk() const;

public:
    ///
    /// \brief GetNext
    ///
    /// Allows iteration with range-for:
    /// \code{cpp}
    ///
    /// ZmwChunkedFastaReader reader{fn, numChunks};
    /// reader.Chunk(4);
    /// for (const FastaSequence& seq : reader) {
    ///     // do stuff with seq
    /// }
    /// \endcode
    ///
    /// or you can iterate 'manually':
    /// \code{cpp}
    ///
    /// ZmwChunkedFastaReader reader{fn, numChunks};
    /// reader.Chunk(4);
    /// FastaSequence seq;
    /// while (reader.GetNext(seq)) {
    ///     // do stuff with seq
    /// }
    /// \endcode
    ///
    /// \param[out] record
    /// \return success/failure
    ///
    bool GetNext(FastaSequence& record);

private:
    class ZmwChunkedFastaReaderPrivate;
    std::unique_ptr<ZmwChunkedFastaReaderPrivate> d_;
};

}  // namespace BAM
}  // namespace PacBio

#endif  // ZMWCHUNKEDFASTAREADER_H

==> pbbam_1.6.0+dfsg.orig.tar.xz: pbbam-1.6.0/include/pbbam/ZmwChunkedFastaReader.h <==
#ifndef PBBAM_ZMWCHUNKEDFASTAREADER_H
#define PBBAM_ZMWCHUNKEDFASTAREADER_H

#include <pbbam/Config.h>

#include <memory>
#include <string>
#include <vector>

#include <pbbam/FastaSequence.h>
#include <pbbam/internal/QueryBase.h>

namespace PacBio {
namespace BAM {

///
/// \brief The ZmwChunkedFastaReader provides sequential access to FASTA records,
///         where iteration is bounded by chunks of (unique) ZMWs.
///
class ZmwChunkedFastaReader : public internal::QueryBase<FastaSequence>
{
public:
    ///
    /// Construct a new ZMW-chunked FASTA reader.
    ///
    /// \param fn           FASTA file, must have a *.fai index
    /// \param numChunks    desired number of chunks
    ///
    /// Actual chunk count may be smaller than the requested number, if the input
    /// size is smaller.
    ///
    ZmwChunkedFastaReader(const std::string& fn, const size_t numChunks);

    ZmwChunkedFastaReader(ZmwChunkedFastaReader&&) noexcept;
    ZmwChunkedFastaReader& operator=(ZmwChunkedFastaReader&&) noexcept;
    ~ZmwChunkedFastaReader();

    ///
    /// \returns the number of chunks available.
    ///
    /// Actual chunk count may be smaller than the requested number, if the input
    /// size is smaller.
    ///
    size_t NumChunks() const;

    ///
    /// Sets current chunk to start iterating over.
    ///
    ZmwChunkedFastaReader& Chunk(size_t chunkId);

    ///
    /// \returns the current chunk in use
    ///
    size_t Chunk() const;

public:
    ///
    /// \brief GetNext
    ///
    /// Allows iteration with range-for:
    /// \code{cpp}
    ///
    /// ZmwChunkedFastaReader reader{fn, numChunks};
    /// reader.Chunk(4);
    /// for (const FastaSequence& seq : reader) {
    ///     // do stuff with seq
    /// }
    /// \endcode
    ///
    /// or you can iterate 'manually':
    /// \code{cpp}
    ///
    /// ZmwChunkedFastaReader reader{fn, numChunks};
    /// reader.Chunk(4);
    /// FastaSequence seq;
    /// while (reader.GetNext(seq)) {
    ///     // do stuff with seq
    /// }
    /// \endcode
    ///
    /// \param[out] record
    /// \return success/failure
    ///
    bool GetNext(FastaSequence& record);

private:
    class ZmwChunkedFastaReaderPrivate;
    std::unique_ptr<ZmwChunkedFastaReaderPrivate> d_;
};

}  // namespace BAM
}  // namespace PacBio

#endif  // PBBAM_ZMWCHUNKEDFASTAREADER_H
